summaryrefslogtreecommitdiff
path: root/lang/perl5.16/files/patch-lib_pm
blob: b3299535adfd3830c20f502c415d82000288484b (plain) (blame)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
$FreeBSD$

--- lib/lib_pm.PL.orig	Wed Jun  5 03:05:46 2002
+++ lib/lib_pm.PL	Tue Aug 20 21:32:55 2002
@@ -71,30 +71,31 @@ sub import {
 
     my %names;
     foreach (reverse @_) {
-	if ($_ eq '') {
+	my $path = $_;
+	if ($path eq '') {
 	    require Carp;
 	    Carp::carp("Empty compile time value given to use lib");
 	}
 
-	local $_ = _nativize($_);
+	$path = _nativize($path);
 
-	if (-e && ! -d _) {
+	if (-e $path && ! -d _) {
 	    require Carp;
 	    Carp::carp("Parameter to use lib must be directory, not file");
 	}
-	unshift(@INC, $_);
+	unshift(@INC, $path);
 	# Add any previous version directories we found at configure time
 	foreach my $incver (@inc_version_list)
 	{
 	    my $dir = $Is_MacOS
-		? File::Spec->catdir( $_, $incver )
-		: "$_/$incver";
+		? File::Spec->catdir( $path, $incver )
+		: "$path/$incver";
 	    unshift(@INC, $dir) if -d $dir;
 	}
 	# Put a corresponding archlib directory in front of $_ if it
 	# looks like $_ has an archlib directory below it.
 	my($arch_auto_dir, $arch_dir, $version_dir, $version_arch_dir)
-	    = _get_dirs($_);
+	    = _get_dirs($path);
 	unshift(@INC, $arch_dir)         if -d $arch_auto_dir;
 	unshift(@INC, $version_dir)      if -d $version_dir;
 	unshift(@INC, $version_arch_dir) if -d $version_arch_dir;
@@ -71,30 +71,31 @@ sub import {
 	    unshift(@INC, $dir) if -d $dir;
 	}
-	# Put a corresponding archlib directory in front of $_ if it
-	# looks like $_ has an archlib directory below it.
+	# Put a corresponding archlib directory in front of $path if it
+	# looks like $path has an archlib directory below it.
 	my($arch_auto_dir, $arch_dir, $version_dir, $version_arch_dir)